import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const web = [
  {
    path: '/',
    name: 'index',
    meta: { title: '网站首页' },
    component: () => import('../views/index.vue'),
  },
  {
    path: '/apply',
    name: 'apply',
    meta: { title: '我要申领' },
    component: () => import('../views/apply/index.vue'),
  },
  {
    path: '/apply/detail',
    name: 'apply_detail',
    meta: { title: '创新券详情' },
    component: () => import('../views/apply/detail.vue'),
  },
  {
    path: '/apply/apply',
    name: 'apply_apply',
    meta: { title: '创新券申领' },
    component: () => import('../views/apply/apply.vue'),
  },
  {
    path: '/cashing/quota',
    name: 'cashing_quota',
    meta: { title: '我的额度' },
    component: () => import('../views/cashing/quota.vue'),
  },
  {
    path: '/cashing/quota/detail',
    name: 'cashing_quota_detail',
    meta: { title: '我的额度-详情' },
    component: () => import('../views/cashing/quota-detail.vue'),
  },
  {
    path: '/cashing/order',
    name: 'cashing_order',
    meta: { title: '我的订单' },
    component: () => import('../views/cashing/order.vue'),
  },
  {
    path: '/cashing/order/detail',
    name: 'cashing_order_detail',
    meta: { title: '我的订单-详情' },
    component: () => import('../views/cashing/order-detail.vue'),
  },
  {
    path: '/service/unscramble',
    name: 'service_unscramble',
    meta: { title: '政策解读' },
    component: () => import('../views/service/unscramble.vue'),
  },
  {
    path: '/service/unscramble/detail',
    name: 'service_unscramble_detail',
    meta: { title: '政策解读' },
    component: () => import('../views/service/unscramble-detail.vue'),
  },
  {
    path: '/service/mechanism',
    name: 'service_mechanism',
    meta: { title: '服务机构' },
    component: () => import('../views/service/mechanism.vue'),
  },
  {
    path: '/service/account',
    name: 'service_account',
    meta: { title: '个人中心' },
    component: () => import('../views/service/account.vue'),
  },
  {
    path: '/service/account/base',
    name: 'service_account_base',
    meta: { title: '个人中心-基础信息' },
    component: () => import('../views/service/account/base.vue'),
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '登录', key: 'login' },
    component: () => import('../views/login.vue'),
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.path == '/apply' || to.path == '/cashing/quota' || to.path == '/service/unscramble') {
    if (!token) {
      next(`/login?path=${to.path}`);
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
